==> haskell-constraints-extras-0.4.0.0-73-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 constraints-extras
version:              0.4.0.0
visibility:           public
id:                   constraints-extras-0.4.0.0-3p37kLSfD3JF2Q2cvAVNVv
key:                  constraints-extras-0.4.0.0-3p37kLSfD3JF2Q2cvAVNVv
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  94d4a3381fb5d1912532ed36f8977cca
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.2.8/site-local/constraints-extras-0.4.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/constraints-extras-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.4.0.0-3p37kLSfD3JF2Q2cvAVNVv
depends:
    base-4.16.4.0 constraints-0.13.4-GFhWVzlWYYG4WPmBIHVTaj
    template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-extras-0.4.0.1-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 constraints-extras
version:              0.4.0.1
visibility:           public
id:                   constraints-extras-0.4.0.1-1ohSO2MUFiNA1kfAGswIng
key:                  constraints-extras-0.4.0.1-1ohSO2MUFiNA1kfAGswIng
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  f2945afba88fcf2db348b7892b905835
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.2.8/site-local/constraints-extras-0.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/constraints-extras-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.4.0.1-1ohSO2MUFiNA1kfAGswIng
depends:
    base-4.16.4.0 constraints-0.13.4-7zdNhBEZCHL204LP1Lqk4K
    template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
